==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/TypicalPriceIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { TypicalPriceIndicatorDescription } from "./TypicalPriceIndicatorDescription";
/**
 * @hidden
 */
export let TypicalPriceIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class TypicalPriceIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (TypicalPriceIndicatorDescriptionMetadata.a == null) {
                TypicalPriceIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TypicalPriceIndicatorDescriptionMetadata.c(TypicalPriceIndicatorDescriptionMetadata.a);
            }
            if (a.j(TypicalPriceIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.y(TypicalPriceIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
        }
        static d(a) {
            TypicalPriceIndicatorDescriptionMetadata.b(a);
            a.aa("TypicalPriceIndicator", () => new TypicalPriceIndicatorDescription());
            a.z("TypicalPriceIndicator", TypicalPriceIndicatorDescriptionMetadata.a);
        }
    }
    TypicalPriceIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(TypicalPriceIndicatorDescriptionMetadata, 'TypicalPriceIndicatorDescriptionMetadata');
    TypicalPriceIndicatorDescriptionMetadata.a = null;
    return TypicalPriceIndicatorDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/TypicalPriceIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { TypicalPriceIndicatorDescription } from "./TypicalPriceIndicatorDescription";
/**
 * @hidden
 */
export let TypicalPriceIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class TypicalPriceIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (TypicalPriceIndicatorDescriptionMetadata.a == null) {
                TypicalPriceIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TypicalPriceIndicatorDescriptionMetadata.c(TypicalPriceIndicatorDescriptionMetadata.a);
            }
            if (a.k(TypicalPriceIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.aa(TypicalPriceIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
        }
        static d(a) {
            TypicalPriceIndicatorDescriptionMetadata.b(a);
            a.ac("TypicalPriceIndicator", () => new TypicalPriceIndicatorDescription());
            a.ab("TypicalPriceIndicator", TypicalPriceIndicatorDescriptionMetadata.a);
        }
    }
    TypicalPriceIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(TypicalPriceIndicatorDescriptionMetadata, 'TypicalPriceIndicatorDescriptionMetadata');
    TypicalPriceIndicatorDescriptionMetadata.a = null;
    return TypicalPriceIndicatorDescriptionMetadata;
})();
